diff Core/HttpServer/EmbeddedResourceHttpHandler.h @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 3959d33612cc
children c996319e90bc
line wrap: on
line diff
--- a/Core/HttpServer/EmbeddedResourceHttpHandler.h	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/HttpServer/EmbeddedResourceHttpHandler.h	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,7 +25,7 @@
 #include <EmbeddedResources.h>   // Autogenerated file
 #include <boost/shared_ptr.hpp>
 
-namespace Palantir
+namespace Palanthir
 {
   class EmbeddedResourceHttpHandler : public HttpHandler
   {
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium